mailr19160 - in /trunk: lib/ lib/opendx/ lib/software/ lib/software/opendx/ pipe_control/ test_suite/unit_tests/_lib/_opendx/ te...


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on March 26, 2013 - 15:23:
Author: bugman
Date: Tue Mar 26 15:23:56 2013
New Revision: 19160

URL: http://svn.gna.org/viewcvs/relax?rev=19160&view=rev
Log:
Shifted the lib.opendx package to lib.software.opendx.


Added:
    trunk/lib/software/opendx/
      - copied from r19158, trunk/lib/opendx/
    trunk/test_suite/unit_tests/_lib/_software/_opendx/
      - copied from r19158, trunk/test_suite/unit_tests/_lib/_opendx/
Removed:
    trunk/lib/opendx/
    trunk/test_suite/unit_tests/_lib/_opendx/
Modified:
    trunk/lib/__init__.py
    trunk/lib/software/__init__.py
    trunk/pipe_control/opendx.py
    trunk/test_suite/unit_tests/_lib/_software/__init__.py
    trunk/test_suite/unit_tests/_lib/_software/_opendx/test___init__.py
    trunk/user_functions/dx.py

Modified: trunk/lib/__init__.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/lib/__init__.py?rev=19160&r1=19159&r2=19160&view=diff
==============================================================================
--- trunk/lib/__init__.py (original)
+++ trunk/lib/__init__.py Tue Mar 26 15:23:56 2013
@@ -38,7 +38,6 @@
     'io',
     'linear_algebra',
     'model_selection',
-    'opendx',
     'order',
     'physical_constants',
     'regex',

Modified: trunk/lib/software/__init__.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/lib/software/__init__.py?rev=19160&r1=19159&r2=19160&view=diff
==============================================================================
--- trunk/lib/software/__init__.py (original)
+++ trunk/lib/software/__init__.py Tue Mar 26 15:23:56 2013
@@ -23,5 +23,6 @@
 """The relax-lib NMR package - a library of functions for creating input, 
reading output and control of external software."""
 
 __all__ = [
-    'grace'
+    'grace',
+    'opendx'
 ]

Modified: trunk/pipe_control/opendx.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/pipe_control/opendx.py?rev=19160&r1=19159&r2=19160&view=diff
==============================================================================
--- trunk/pipe_control/opendx.py (original)
+++ trunk/pipe_control/opendx.py Tue Mar 26 15:23:56 2013
@@ -33,7 +33,7 @@
 from pipe_control import value
 from lib.errors import RelaxError, RelaxUnknownParamError
 from lib.io import open_write_file
-from lib.opendx.files import write_config, write_general, write_point, 
write_program
+from lib.software.opendx.files import write_config, write_general, 
write_point, write_program
 from specific_analyses.setup import get_specific_fn
 
 

Modified: trunk/test_suite/unit_tests/_lib/_software/__init__.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/test_suite/unit_tests/_lib/_software/__init__.py?rev=19160&r1=19159&r2=19160&view=diff
==============================================================================
--- trunk/user_functions/dx.py (original)
+++ trunk/user_functions/dx.py Tue Mar 26 15:23:56 2013
@@ -25,7 +25,8 @@
 # relax module imports.
 from pipe_control import diffusion_tensor
 from graphics import WIZARD_IMAGE_PATH
-import lib.opendx.execute
+from lib.software.opendx import execute
+from lib.software.opendx import map
 import pipe_control.opendx
 from prompt.doc_string import regexp_doc
 from specific_analyses.model_free import Model_free
@@ -78,7 +79,7 @@
 # Description.
 uf.desc.append(Desc_container())
 uf.desc[-1].add_paragraph("This will execute OpenDX to display the space 
maps created previously by the dx.map user function.  This will work for any 
type of OpenDX map.")
-uf.backend = lib.opendx.execute.run
+uf.backend = run
 uf.menu_text = "&execute"
 uf.gui_icon = "oxygen.categories.applications-education"
 uf.wizard_size = (700, 500)
@@ -204,7 +205,7 @@
 uf.desc[-1].add_paragraph("To map the model-free space 'm4' for residue 2, 
spin N6 defined by the parameters {S2, te, Rex}, name the results 'test', and 
to place the files in the current directory, use one of the following 
commands:")
 uf.desc[-1].add_prompt("relax> dx.map(['s2', 'te', 'rex'], spin_id=':2@N6', 
file_prefix='test', dir=None)")
 uf.desc[-1].add_prompt("relax> dx.map(params=['s2', 'te', 'rex'], 
spin_id=':2@N6', inc=100, file_prefix='test', dir=None)")
-uf.backend = pipe_control.opendx.map
+uf.backend = map
 uf.menu_text = "&map"
 uf.gui_icon = "relax.grid_search"
 uf.wizard_height_desc = 280




Related Messages


Powered by MHonArc, Updated Tue Mar 26 15:40:02 2013
--- trunk/test_suite/unit_tests/_lib/_software/__init__.py (original)
+++ trunk/test_suite/unit_tests/_lib/_software/__init__.py Tue Mar 26 
15:23:56 2013
@@ -21,5 +21,6 @@
 
 
 __all__ = [
+    '_opendx',
     'test___init__'
 ]

Modified: trunk/test_suite/unit_tests/_lib/_software/_opendx/test___init__.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/test_suite/unit_tests/_lib/_software/_opendx/test___init__.py?rev=19160&r1=19158&r2=19160&view=diff
==============================================================================
--- trunk/test_suite/unit_tests/_lib/_software/_opendx/test___init__.py 
(original)
+++ trunk/test_suite/unit_tests/_lib/_software/_opendx/test___init__.py Tue 
Mar 26 15:23:56 2013
@@ -25,15 +25,15 @@
 
 # relax module imports.
 from test_suite.unit_tests.package_checking import PackageTestCase
-import lib.opendx
+import lib.software.opendx
 
 
 class Test___init__(PackageTestCase):
     """Unit tests for the lib.opendx package."""
 
     def setUp(self):
         """Set up for the package checking."""
 
-        self.package = lib.opendx
-        self.package_name = 'lib.opendx'
-        self.package_path = sys.path[0] + sep + 'lib' + sep + 'opendx'
+        self.package = lib.software.opendx
+        self.package_name = 'lib.software.opendx'
+        self.package_path = sys.path[0] + sep + 'lib' + sep + 'software' + 
@@ -25,15 +25,15 @@
 
 class Test___init__(PackageTestCase):
-    """Unit tests for the lib.opendx package."""
+    """Unit tests for the lib.software.opendx package."""
 
     def setUp(self):
sep + 'opendx'

Modified: trunk/user_functions/dx.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/user_functions/dx.py?rev=19160&r1=19159&r2=19160&view=diff
==============================================================================